<?php
/**
  * SquirrelMail mobile Plugin
  *
  * @copyright &copy; 2007, Norihisa Washitake (http://washitake.com/)
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
  * @version $Id$
  * @package plugins
  * @subpackage mobile
  */

include_once("user_agent.php");


/**
  * Add link to menu at top of content pane
  *
  * @return void
  *
  */
function mobile_page_header_template_do()
{
   global $oTemplate;

   sq_change_text_domain('mobile');
   $nbsp = $oTemplate->fetch('non_breaking_space.tpl');
   $output = makeInternalLink('plugins/mobile/options.php', _("mobile"), '')
           . $nbsp . $nbsp;
   sq_change_text_domain('squirrelmail');

   return array('menuline' => $output);
}



/**
  * Inserts an option block in the main SM options page
  *
  */
function mobile_option_link_do()
{
   global $optpage_blocks;

   sq_change_text_domain('mobile');

   $optpage_blocks[] = array(
      'name' => _("mobile"),
      'url' => sqm_baseuri() . 'plugins/mobile/options.php',
      'desc' => _("Mobile plugin allows you to access SquirrelMail from your mobile phone."),
      'js' => FALSE
   );

   sq_change_text_domain('squirrelmail');

}



/**
  * Validate that this plugin is configured correctly
  *
  * @return boolean Whether or not there was a
  *                 configuration error for this plugin.
  *
  */
function mobile_check_configuration_do()
{

   // test for something that this plugin requires, print error if
   // misconfigured or requirements are missing
   //
   if (FALSE)  // put something meaningful here
   {
      do_err('mobile plugin is missing something important', FALSE);
      return TRUE;  // return FALSE if you only want to display a non-critical error
   }

   return FALSE;

}


function mobile_config_override_do()
{
	$ua = mobile_get_ua_type();

	if ($ua != "") {
		$ua_template_name = mobile_get_template_name($ua);
		global $sTemplate, $aTemplateSet, $templateset_default;
		global $icon_theme;

		$sTemplate = $ua_template_name;
		$templateset_default = $ua_template_name;

		if (!isset($aTemplateSet) || !is_array($aTemplateSet)) {
			$aTemplateSet = array();
		}
		if (! is_array($aTemplateSet[0]))
			$aTemplateSet[0] = array();

		$aTemplateSet[0]['ID']   = $ua_template_name;
		$aTemplateSet[0]['NAME'] = "Mobile Template ($ua)";

		$icon_theme = 'theme';
	} else {
		// reset ua to null if template not exists.
		global $sqm_mobile_ua_type;
		$sqm_mobile_ua_type = "";
		$ua = "";
	}

	if (! mobile_ua_accept_cookie()) {
		sqsession_register(TRUE, "auth_without_cookie");
	}
}

function mobile_get_pref_override_do(&$temp)
{
	$key = $temp[1];

	if ($key == 'truncate_sender' || $key == 'truncate_subject') {
		/* truncating sender and subject on message display */
		return mobile_get_ua_screenchars();
	}
	else if ($key == 'language') {
		/* FIXME: not implemented yet! */
		/* should we return 'ja_JP.SJIS' for mobile profiles? */
		return null;
	}

	return null;
}

function mobile_add_session_param($uri='', $is_header = false)
{
	if (mobile_ua_accept_cookie())
		return $uri;

	$amp = ($is_header) ? '&' : '&amp;';

	$session_param = sprintf("%s=%s", session_name(), session_id());
	
	$secretkey = $onetimepad = $key = "";
	if (sqgetGlobalVar('secretkey', $secretkey)) {
		sqgetGlobalVar('onetimepad', $onetimepad, SQ_SESSION);
		$key = OneTimePadEncrypt($secretkey, $onetimepad);
		$session_param .= $amp . 'key=' . $key;
	} else if (sqgetGlobalVar('key', $key, SQ_GET)) {
		$session_param .= $amp . 'key=' . $key;
	}

	if ($uri == "")
		return $session_param;
	else if (strstr($uri, $session_param))
		return $uri;
	else if (strchr($uri, '?'))
		return $uri . $amp . $session_param;
	else
		return $uri . '?' . $session_param;
}

function mobile_redirect_before_do(&$redirect_url)
{
	$ua = mobile_get_ua_type();

	if ($ua != "") {

		if (preg_match('/webmail.php$/', $redirect_url)) {
			$url = preg_replace('/webmail.php/', 'right_main.php', $redirect_url);
		} else {
			$url = preg_replace('/webmail.php\?right_frame=/', 'right_main.php?', $redirect_url);
		}

		$url = mobile_add_session_param($url, TRUE);

		header("Location: $url");
		exit;
	}
}

function mobile_get_template_name($ua)
{
	$prefix = "mobile_";

	if (mobile_template_exists($prefix.$ua))
		return $prefix.$ua;

	/* if template does not exist, do fallback */
	if (mobile_template_exists($prefix."default"))
		return $prefix."default";

	/* no templateset yet? may be it's not installed... */
	return "default";
}

/* check if the new template exist */
function mobile_template_exists($templatename)
{
	$template_config_file = SM_PATH
		. Template::calculate_template_file_directory($templatename)
		. 'config.php';
	return (file_exists($template_config_file));
}

/* belows are from original source, png => gif */

/**
 * Function to retrieve correct icon based on provided message flags.  This is
 * a merge/replacement for getFlagIcon() and getFlagText() functions.
 *
 * @param array $aFlags associative array with seen,deleted,anwered and flag keys.
 * @param string $icon_theme_path path to user's currently selected icon theme.
 * @return string $icon full HTML img tag or text icon, depending on of user prefs
 * @author Steve Brown
 */
function mobile_getFlagIcon ($aFlags, $icon_theme_path)
{
	if (mobile_ua_has_png_support())
		return getFlagIcon($aFlags, $icon_theme_path);

	/**
	 * 0  = unseen
	 * 1  = seen
	 * 2  = deleted
	 * 3  = deleted seen
	 * 4  = answered
	 * 5  = answered seen
	 * 6  = answered deleted
	 * 7  = answered deleted seen
	 * 8  = flagged
	 * 9  = flagged seen
	 * 10 = flagged deleted
	 * 11 = flagged deleted seen
	 * 12 = flagged answered
	 * 13 = flagged aswered seen
	 * 14 = flagged answered deleted
	 * 15 = flagged anserwed deleted seen
	 */

	/**
	 * Use static vars to avoid initialisation of the array on each displayed row
	 */
	static $flag_icons, $flag_values;
	if (!isset($flag_icons)) {
		// This is by no means complete...
		$flag_icons = array (   //     Image icon name               Text Icon  Alt/Title Text
				array ('msg_new.gif',                '&nbsp;',  '('._("New").')') ,
				array ('msg_read.gif',               '&nbsp;',  '('._("Read").')'),
				array ('msg_new_deleted.gif',        _("D"),    '('._("Deleted").')'),
				array ('msg_read_deleted.gif',       _("D"),    '('._("Deleted").')'),
				array ('msg_new_reply.gif',          _("A"),    '('._("Answered").')'),
				array ('msg_read_reply.gif',         _("A"),    '('._("Answered").')'),
				array ('msg_read_deleted_reply.gif', _("D"),    '('._("Answered").')'),
				array ('flagged.gif',                _("F"),    '('._("Flagged").')'),
				array ('flagged.gif',                _("F"),    '('._("Flagged").')'),
				array ('flagged.gif',                _("F"),    '('._("Flagged").')'),
				array ('flagged.gif',                _("F"),    '('._("Flagged").')'),
				array ('flagged.gif',                _("F"),    '('._("Flagged").')'),
				array ('flagged.gif',                _("F"),    '('._("Flagged").')'),
				array ('flagged.gif',                _("F"),    '('._("Flagged").')'),
				array ('flagged.gif',                _("F"),    '('._("Flagged").')'),
				array ('flagged.gif',                _("F"),    '('._("Flagged").')')
				);

		$flag_values = array('seen'     => 1,
				'deleted'  => 2,
				'answered' => 4,
				'flagged'  => 8,
				'draft'    => 16);
	}

	/**
	 * The flags entry contain all items displayed in the flag column.
	 */
	$icon = '';

	$index = 0;
	foreach ($aFlags as $flag => $flagvalue) {
		switch ($flag) {
			case 'deleted':
			case 'answered':
			case 'seen':
			case 'flagged': if ($flagvalue) $index += $flag_values[$flag]; break;
			default: break;
		}
	}

	if (isset($flag_icons[$index])) {
		$data = $flag_icons[$index];
	} else {
		$data = end($flag_icons);
	}

	$icon = getIcon($icon_theme_path, $data[0], $data[1], $data[2]);
	return $icon;
}


/**
 * Function to retrieve correct priority icon based on user prefs
 *
 * @param integer $priority priority value of message
 * @param string $icon_theme_path path to user's currently selected icon theme.
 * @return string $icon full HTML img tag or text icon, depending on of user prefs
 * @author Steve Brown
 */
function mobile_getPriorityIcon ($priority, $icon_theme_path)
{
	if (mobile_ua_has_png_support())
		return getPriorityIcon($priority, $icon_theme_path);

	$icon = '';

	switch ($priority) {
		case 1:
		case 2:
			$icon = getIcon($icon_theme_path, 'prio_high.gif', create_span('!', 'high_priority'), _("High priority"));
			break;
		case 5:
			$icon = getIcon($icon_theme_path, 'prio_low.gif', create_span('&#8595;', 'low_priority'), _("Low priority"));
			break;
		default:
			$icon = '';
			break;
	}

	return $icon;
}


/**
 * Function to retrieve correct attchment icon based on user prefs
 *
 * @param boolean $attach TRUE if the message has an attachment
 * @param string $icon_theme_path path to user's currently selected icon theme.
 * @return string $icon full HTML img tag or text icon, depending on of user prefs
 * @author Steve Brown
 */
function mobile_getAttachmentIcon ($attach, $icon_theme_path)
{
	if (mobile_ua_has_png_support())
		return getAttachmentIcon ($attach, $icon_theme_path);

	$icon = '';

	if ($attach) {
		$icon = getIcon($icon_theme_path, 'attach.gif', '+', _('Attachment'));
	}

	return $icon;
}

