<?php

/**
 * paginator_util.php
 *
 * The following functions are utility functions for templates. Do not
 * echo output in these functions.
 *
 * @copyright &copy; 2005-2006 The SquirrelMail Project Team
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
 * @version $Id: paginator_util.php 12066 2007-01-05 03:39:22Z pdontthink $
 * @package squirrelmail
 */


include_once(SM_PATH . 'plugins/mobile/functions.php');


/**
 * Generate a paginator link.
 *
 * @param string  $box Mailbox name
 * @param integer $start_msg Message Offset
 * @param string  $text text used for paginator link
 * @return string
 */
function mobile_get_paginator_link($box, $start_msg, $text, $accesskey)
{
	sqgetGlobalVar('PHP_SELF',$php_self,SQ_SERVER);
	return create_hyperlink(
			mobile_add_session_param("$php_self?startMessage=$start_msg&amp;mailbox=$box"),
			$text, '', '', '', '', '',
			(!empty($accesskey) ? array("accesskey" => $accesskey) : array())
	);
}


/**
 * This function computes the comapact paginator string.
 *
 * @param string  $box           mailbox name
 * @param integer $iOffset       offset in total number of messages
 * @param integer $iTotal        total number of messages
 * @param integer $iLimit        maximum number of messages to show on a page
 *
 * @return string $result   paginate string with links to pages
 *
 */
function mobile_get_paginator_str($box, $iOffset, $iTotal, $iLimit)
{

	global $oTemplate;

	// keeps count of how many times
	// the paginator is used, avoids
	// duplicate naming of <select> 
	// and GO button
	static $display_iterations = 0; 
	$display_iterations++;

	sqgetGlobalVar('PHP_SELF',$php_self,SQ_SERVER);

	/* Initialize paginator string chunks. */
	$prv_str = '';
	$nxt_str = '';

	$box = urlencode($box);

	/* Create simple strings that will be creating the paginator. */
	/* This will be used as a space. */
	$spc = $oTemplate->fetch('non_breaking_space.tpl');
	/* This will be used as a seperator. */
	$sep = '|';

	/* Make sure that our start message number is not too big. */
	$iOffset = min($iOffset, $iTotal);

	/* Compute the starting message of the previous and next page group. */
	$next_grp = $iOffset + $iLimit;
	$prev_grp = $iOffset - $iLimit;

	/* Compute the basic previous and next strings. */

	/* Page selector block. Following code computes page links. */
	if ($iLimit != 0 && ($iTotal > $iLimit)) {
		/* Most importantly, what is the current page!!! */
		$cur_pg = intval($iOffset / $iLimit) + 1;

		/* Compute total # of pages and # of paginator page links. */
		$tot_pgs = ceil($iTotal / $iLimit);  /* Total number of Pages */

		$last_grp = (($tot_pgs - 1) * $iLimit) + 1;
	}

	/* Put all the pieces of the paginator string together. */
	/**
	 * Hairy code... But let's leave it like it is since I am not certain
	 * a different approach would be any easier to read. ;)
	 */
	$result = mobile_get_paginator_link($box, 1, '&laquo;');

	$result .= '&nbsp;';

	$result .= ($prev_grp >= 0)
	         ?  mobile_get_paginator_link($box, $prev_grp, _("Previous"), 4)
	         : _("Previous");

	$result .= ' | ';

	$result .= ($next_grp <= $iTotal)
	         ? mobile_get_paginator_link($box, $next_grp, _("Next"), 6)
	         : _("Next");

	$result .= '&nbsp;';

	$result .= mobile_get_paginator_link($box, $last_grp, '&raquo;');

	/* Return our final magical paginator string. */
	return ($result);
}
