<?php

/**
  * User agent detection.
  *
  * @copyright &copy; 2007, Norihisa Washitake. (http://washitake.com/)
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
  * @version $Id$
  * @package plugins
  * @subpackage mobile
  */

include_once(SM_PATH . 'functions/global.php');

/* check the browser type, returns its "carrier" (service provider) name. */
function mobile_get_ua_type()
{
	global $sqm_mobile_enabled;
	global $sqm_mobile_ua_type;

	/*
	 * if mobile option is disabled by user preference,
	 * returns a default value ("").
	 */
	if (! isset($sqm_mobile_enabled)) {
		global $data_dir, $username;
		if ($username != "") {
			$enabled = getPref($data_dir, $username, "mobile_enabled", "enabled");
			$sqm_mobile_enabled = ($enabled != "disabled");
		} else {
			$sqm_mobile_enabled = true;
		}
	}
	if ($sqm_mobile_enabled == false) {
		return "";
	}


	if (! isset($sqm_mobile_ua_type)) {

		/* check user_agent first. */
		$user_agent = "";
		if (! sqgetGlobalVar('HTTP_USER_AGENT', $user_agent, SQ_SERVER)) {

			$sqm_mobile_ua_type = "";

		} else {

			$ua_map = array(
				'/^DoCoMo/i'               => 'docomo',
				'/^UP\. ?Browser/'         => 'au',
				'/^KDDI-.*UP\. ?Browser/'  => 'au',
				'/SoftBank/i'              => 'softbank',
				'/Vodafone/i'              => 'softbank',
				'/J-PHONE/i'               => 'softbank',
				'/J-EMULATOR/i'            => 'softbank',
				'/MOT/i'                   => 'other',
				'/(WILLCOM|DDIPOCKET)/i'   => 'other',
				'/Lynx/'                   => 'other',
			);

			$matched = "";
			while (list($key, $val) = each($ua_map)) {
				if (preg_match($key, $user_agent))
					$matched = $val;
			}

			/* for debug */
			if ($matched == "")
				$matched = "au";

			$sqm_mobile_ua_type = $matched;
		}
	}

	return $sqm_mobile_ua_type;
}

function mobile_get_ua_screenchars($default='')
{
    $ua = mobile_get_ua_type();

	if ($ua == '') {
		/* If user agent is not a mobile browser,
		 * return the default value of original SquirrelMail.
		 * Don't try to use user preference, then.
		 */
		return 50;
	}

    if ($ua == 'au') {
        /* AU phones has auto-omitting/scrolling features. */
		/* Negative value will be led to no truncation. */
		return -1;
	}

    if (sqgetGlobalVar('HTTP_X_UP_DEVCAP_SCREENCHARS', $chars, SQ_SERVER)) {
		if (($p = strchr($chars, ',')) > 0)
			$chars = substr($chars, 0, $p);
        return ($chars - 1);
	}

	if ($default == '') {
		global $data_dir, $username;
		$default = getPref($data_dir, $username, "mobile_chars_per_line", 20);
	}

    return $default;
}

function mobile_ua_has_png_support()
{
	static $sqm_accept_png;

	if (! isset($sqm_accept_png)) {
		$sqm_accept_png = FALSE;

		$http_accept = $iscolor = '';
		sqgetGlobalVar("HTTP_ACCEPT", $http_accept, SQ_SERVER);
		sqgetGlobalVar("HTTP_X_UP_DEVCAP_ISCOLOR", $iscolor, SQ_SERVER);

		if (strpos($http_accept, "image/png")) {
			$sqm_accept_png = TRUE;
		} else {
			$ua = mobile_get_ua_type();
			if ($ua == "softbank" || $ua == "astel")
				$sqm_accept_png = TRUE;
			else if ($ua == "au" && $iscolor > 0)
				$sqm_accept_png = TRUE;
		}
	}

	return $sqm_accept_png;

}

function mobile_ua_accept_cookie()
{
	static $sqm_ua_accept_cookie;

	if (! isset($sqm_ua_accept_cookie)) {
		$sqm_ua_accept_cookie = TRUE;

		$ua = mobile_get_ua_type();
		if ($ua == "docomo") {
			$sqm_ua_accept_cookie = FALSE;
		}
	}

	return $sqm_ua_accept_cookie;
}


?>
